@@ -761,7 +761,12 @@ class Base(object):
             elif response.status == 404:
                 raise NotFoundError(response.status, "Node or property not found")
             else:
-                raise StatusException(response.status, "Invalid data sent")
+                msg = "Invalid data sent"
+                try:
+                    msg += ": " + json.loads(content).get('message')
+                except (ValueError, AttributeError, KeyError):
+                    pass
+                raise StatusException(response.status, msg)
 
     def set(self, key, value, tx=None):
         tx = Transaction.get_transaction(tx)
@@ -782,9 +787,9 @@ class Base(object):
                 raise KeyError()
             else:
                 raise NotFoundError(response.status,
-                                    "Node or propery not found")
+                                    "Node or property not found")
         else:
-            raise StatusException(response.status, "Node or propery not found")
+            raise StatusException(response.status, "Node or property not found")
 
     def __len__(self):
         return len(self._dic["data"])
@@ -839,7 +844,12 @@ class Base(object):
             self._update_dict_data()
             return props
         elif response.status == 400:
-            raise StatusException(response.status, "Invalid data sent")
+            msg = "Invalid data sent"
+            try:
+                msg += ": " + json.loads(content).get('message')
+            except (ValueError, AttributeError, KeyError):
+                pass
+            raise StatusException(response.status, msg)
         else:
             raise NotFoundError(response.status, "Properties not found")
 
@@ -976,7 +986,12 @@ class Node(Base):
                                                      "URI not of \"to\" node" \
                                                      "not found")
             else:
-                raise StatusException(response.status, "Invalid data sent")
+                msg = "Invalid data sent"
+                try:
+                    msg += ": " + json.loads(content).get('message')
+                except (ValueError, AttributeError, KeyError):
+                    pass
+                raise StatusException(response.status, msg)
         return relationship
 
     # HACK: Special methods for handle pickling manually
@@ -1092,7 +1107,12 @@ class Node(Base):
                 raise NotFoundError(response.status, "Node or relationship " \
                                                      "not found")
             else:
-                raise StatusException(response.status, "Invalid data sent")
+                msg = "Invalid data sent"
+                try:
+                    msg += ": " + json.loads(content).get('message')
+                except (ValueError, AttributeError, KeyError):
+                    pass
+                raise StatusException(response.status, msg)
 
 
 class PaginatedTraversal(object):
@@ -1225,7 +1245,12 @@ class IndexesProxy(dict):
                                              auth=self._auth,
                                              **result_dict)
                 else:
-                    raise StatusException(response.status, "Invalid data sent")
+                    msg = "Invalid data sent"
+                    try:
+                        msg += ": " + json.loads(content).get('message')
+                    except (ValueError, AttributeError, KeyError):
+                        pass
+                    raise StatusException(response.status, msg)
             return self._dict[name]
 
     def get(self, attr, *args, **kwargs):
@@ -1305,7 +1330,8 @@ class Index(object):
                 value = value.get_value()
             tx = Transaction.get_transaction(tx)
             url = "%s/%s" % (self.url, smart_quote(value))
-            return Index._get_results(url, self._index_for, auth=self._auth, tx=tx)
+            return Index._get_results(url, self._index_for, auth=self._auth,
+                                      tx=tx)
 
         def __setitem__(self, value, item):
             tx = self.tx
@@ -1491,7 +1517,7 @@ class Index(object):
                             'and a query) (%d given)' % (len(args) + 1))
         elif len(args) == 1:
             query, = args
-            return self.get('text').query(str(query))
+            return self.get('text').query(unicode(query))
         else:
             key, query = args
             index_key = self.get(key)
@@ -1501,7 +1527,7 @@ class Index(object):
                 if query.fielded:
                     raise ValueError('Queries with an included key should '\
                                      'not include a field.')
-                return index_key.query(str(query))
+                return index_key.query(unicode(query))
 
 
 class RelationshipsProxy(dict):
@@ -1923,7 +1949,12 @@ class Extension(object):
         elif response.status == 404:
             raise NotFoundError(response.status, "Extension not found")
         else:
-            raise StatusException(response.status, "Invalid data sent")
+            msg = "Invalid data sent"
+            try:
+                msg += ": " + json.loads(content)['message']
+            except (ValueError, AttributeError, KeyError, TypeError):
+                pass
+            raise StatusException(response.status, msg)
 
     def __repr__(self):
         return self.__unicode__()
@@ -1972,9 +2003,11 @@ class Extension(object):
 
 
 def smart_quote(val):
-    # TODO: Improve the unicode checking
-    try:
-        safe_key = urllib.quote(val, safe="")
-    except (KeyError, UnicodeEncodeError, UnicodeError):
-        safe_key = urllib.quote(val.encode("utf8"), safe="")
-    return safe_key
+    if isinstance(val, (bool, int, float, long)):
+        return urllib.quote(json.dumps(val), safe="")
+    else:
+        try:
+            safe_key = urllib.quote(val, safe="")
+        except (KeyError, UnicodeEncodeError, UnicodeError):
+            safe_key = urllib.quote(val.encode("utf8"), safe="")
+        return safe_key
