@@ -258,7 +258,7 @@ class IndexesTestCase(RelationshipsTestCase):
     def test_create_index_for_nodes_and_dots(self):
         # From https://github.com/versae/neo4j-rest-client/issues/43
         n1 = self.gdb.nodes.create(name="John.Doe", place="Texas.s")
-        index = self.gdb.nodes.indexes.create(name="doe")
+        index = self.gdb.nodes.indexes.create(name="dots")
         index["surnames.s"]["d.d"] = n1
         self.assertTrue(n1 in index["surnames.s"]["d.d"])
 
@@ -268,6 +268,22 @@ class IndexesTestCase(RelationshipsTestCase):
         index["bands"]["Motörhead"] = n1
         self.assertTrue(n1 in index["bands"]["Motörhead"])
 
+    def test_create_index_for_nodes_and_boolean(self):
+        n1 = self.gdb.nodes.create(name="John", is_real=True, is_fake=False)
+        index = self.gdb.nodes.indexes.create(name="boolean")
+        index["is_real"][True] = n1
+        index["is_fake"][False] = n1
+        self.assertTrue(n1 in index["is_real"][True])
+        self.assertTrue(n1 in index["is_fake"][False])
+
+    def test_create_index_for_nodes_and_number(self):
+        n1 = self.gdb.nodes.create(name="John", age=30, mean=2.7)
+        index = self.gdb.nodes.indexes.create(name="number")
+        index["age"][30] = n1
+        index["mean"][2.7] = n1
+        self.assertTrue(n1 in index["age"][30])
+        self.assertTrue(n1 in index["mean"][2.7])
+
     def test_create_index_for_nodes_url_safe(self):
         n1 = self.gdb.nodes.create(name="Brian", place="AC/DC")
         index = self.gdb.nodes.indexes.create(name="doe")
